@@ -107,9 +107,9 @@ class Plugin(ad.Plugin):  # was: use_eidreader
         super(Plugin, self).on_site_startup(kernel)
 
         if self.data_cache_dir is None:
-            self.data_cache_dir = self.site.cache_dir / 'media' / 'cache' / 'beid'
+            self.data_cache_dir = self.site.site_dir / 'media' / 'cache' / 'beid'
             # self.data_cache_dir = join(
-            #     self.site.cache_dir, 'media', 'beidtmp')
+            #     self.site.site_dir, 'media', 'beidtmp')
         self.site.makedirs_if_missing(self.data_cache_dir)
 
         cmc = list(models_by_base(BeIdCardHolder, toplevel_only=True))
