@@ -95,9 +95,9 @@ class Plugin(ad.Plugin):
         super(Plugin, self).on_site_startup(kernel)
 
         if self.data_cache_dir is None:
-            self.data_cache_dir = self.site.cache_dir / 'media' / 'cache' / 'bnid'
+            self.data_cache_dir = self.site.site_dir / 'media' / 'cache' / 'bnid'
             # self.data_cache_dir = join(
-            #     self.site.cache_dir, 'media', 'bnidtmp')
+            #     self.site.site_dir, 'media', 'bnidtmp')
         self.site.makedirs_if_missing(self.data_cache_dir)
 
         cmc = list(models_by_base(BnIdCardHolder, toplevel_only=True))
