@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2022 Rumma & Ko Ltd
+# Copyright 2011-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -11,8 +11,11 @@ See :ref:`book.specs.cal`.
 
 import datetime
 from dateutil.tz import tzlocal
+from dateutil.parser import parse
+from typing import Union, Any
 
 from django.conf import settings
+from django.utils import timezone
 from django.utils.encoding import force_str
 
 from lino.utils.format_date import format_date
@@ -148,3 +151,66 @@ def update_reminder(type, owner, user, orig, msg, num, unit):
         unit.add_duration(orig, -num),
         msg,
         owner)
+
+
+def resolve_datetime(s: str) -> Union[datetime.datetime, datetime.date]:
+    dt = parse(s)
+    try:
+        dt = timezone.make_naive(dt)
+    except:
+        pass
+    try:
+        dt = timezone.make_aware(dt)
+    except:
+        pass
+    return dt
+
+
+RRULE_RESOLVE = dict(
+    FREQ = lambda x: rt.models.cal.Recurrencies.get_by_name(x.lower()),
+    UNTIL = lambda x: resolve_datetime(x),
+    COUNT = lambda x: int(x),
+    INTERVAL = lambda x: int(x),
+    BYSECOND = lambda x: [int(i) for i in x.split(',')],
+    BYMINUTE = lambda x: [int(i) for i in x.split(',')],
+    BYHOUR = lambda x: [int(i) for i in x.split(',')],
+    # week num (allows negative indexing) weekday ; weekday = "SU" / "MO" / "TU" / "WE" / "TH" / "FR" / "SA"
+    BYDAY = lambda x: [(int(i[:-2]) if i[:-2] != "" else None, i[-2:]) for i in x.split(',')],
+    BYMONTHDAY = lambda x: [int(i) for i in x.split(',')],
+    BYYEARDAY = lambda x: [int(i) for i in x.split(',')],
+    BYWEEKNO = lambda x: [int(i) for i in x.split(',')],
+    BYMONTH = lambda x: [int(i) for i in x.split(',')],
+    BYSETPOS = lambda x: [int(i) for i in x.split(',')],
+    WKST = lambda x: x.split(',')
+)
+
+
+def parse_rrule(rr: str) -> tuple[Any, int, Union[int, datetime.datetime, datetime.date], dict]:
+    """
+
+    Parse the given :term:`recurrence rule` and returns a tuple of `(every_unit,
+    every, max_events, keywords)` where keywords is ...
+
+    """
+
+    # The standards from below specification has been followed while writing this parser
+    #
+    assert rr.startswith('RRULE:')
+    rule = rr.split(':')[1]
+    every_unit = None
+    every = 1
+    limit = None
+    kw = dict()
+    for item in rule.split(';'):
+        key, value = item.split('=')
+        if key == 'FREQ':
+            every_unit = RRULE_RESOLVE[key](value)
+        elif key == 'INTERVAL':
+            every = RRULE_RESOLVE[key](value)
+        elif key == 'UNTIL':
+            limit = RRULE_RESOLVE[key](value)
+        elif key == 'COUNT':
+            limit = RRULE_RESOLVE[key](value)
+        else:
+            kw[key] = RRULE_RESOLVE[key](value)
+    return every_unit, every, limit, kw
