@@ -437,6 +437,8 @@ class DaySlave(AbstractTable):
 
     @classmethod
     def get_master_instance(cls, ar, model, pk):
+        if not pk:
+            pk = 0
         return model(int(pk), ar, cls.calendar_view.navigation_mode, cls.calendar_view.planner)
 
     @classmethod
