@@ -55,6 +55,7 @@ def objects():
     BE = Country.objects.get(pk='BE')
     DE = Country.objects.get(pk='DE')
     FR = Country.objects.get(pk='FR')
+    BD = Country.objects.get(pk='BD')
     eupen = make_city('BE', 'Eupen', zip_code='4700')
     yield eupen
     yield make_city('BE', 'Nispert', type=PlaceTypes.township, parent=eupen)
@@ -79,6 +80,9 @@ def objects():
     yield make_city('BE', 'Cerfontaine', zip_code='5630')
     yield make_city('BE', 'Burdinne', zip_code='4210')
 
+    yield make_city('BD', 'Dhaka')
+    yield make_city('BD', 'Cumilla')
+
     def be_province(de, fr, nl):
         if False:  # AFTER17:
             p = Place(
