@@ -4,7 +4,7 @@
 
 """Adds functionality for managing courses or other activities.
 
-See :doc:`/specs/courses`.
+See :doc:`/plugins/courses`.
 
 """
 
