@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2022 Rumma & Ko Ltd
+# Copyright 2014-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import logging ; logger = logging.getLogger(__name__)
@@ -30,6 +30,7 @@ from lino.modlib.users.mixins import UserAuthored, My
 from lino.modlib.users.choicelists import SiteAdmin
 from lino.modlib.printing.mixins import PrintableType, TypedPrintable
 from lino.modlib.office.roles import OfficeStaff, OfficeOperator
+from lino.mixins.duplicable import Duplicable
 
 from lino_xl.lib.postings.mixins import Postable
 from lino_xl.lib.contacts.mixins import ContactRelated
@@ -42,7 +43,7 @@ from .roles import ExcerptsUser, ExcerptsStaff
 from lino.utils import ONE_DAY, ONE_WEEK
 
 
-class ExcerptType(mixins.BabelNamed, PrintableType, MailableType):
+class ExcerptType(mixins.BabelNamed, PrintableType, MailableType, Duplicable):
     # templates_group = 'excerpts/Excerpt'
 
     class Meta:
@@ -109,7 +110,7 @@ class ExcerptType(mixins.BabelNamed, PrintableType, MailableType):
                     _("Cannot set %(c)s for non.certifiable "
                       "model %(m)s") % dict(
                         c=_("Certifying"), m=mc._meta.verbose_name))
-        super(ExcerptType, self).full_clean(*args, **kwargs)
+        super().full_clean(*args, **kwargs)
 
     def update_siblings(self):
         updated = 0
@@ -126,13 +127,14 @@ class ExcerptType(mixins.BabelNamed, PrintableType, MailableType):
         # primary ExcerptType per model because
         # :func:`set_excerpts_actions` will install these as action on
         # the model.
-        super(ExcerptType, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
         self.update_siblings()
 
     def after_ui_save(self, ar, cw):
-        super(ExcerptType, self).after_ui_save(ar, cw)
+        super().after_ui_save(ar, cw)
         if self.primary:
             ar.set_response(refresh_all=True)
+        settings.SITE.build_site_cache(later=True)
 
     @classmethod
     def get_template_groups(cls):
@@ -256,9 +258,9 @@ class ExcerptTypes(dd.Table):
     @classmethod
     def get_choices_text(self, obj, request, field):
         if field.name == 'content_type':
-            return "%s (%s)" % (
-                dd.full_model_name(obj.model_class()),
-                obj)
+            m = obj.model_class()
+            if m is not None:
+                return "%s (%s)" % (dd.full_model_name(m), obj)
         return obj.get_choices_text(request, self, field)
 
 
@@ -271,7 +273,7 @@ class CreateExcerpt(dd.Action):
 
     def __init__(self, etype, *args, **kwargs):
         self.excerpt_type = etype
-        super(CreateExcerpt, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def run_from_ui(self, ar, **kw):
         et = self.excerpt_type
@@ -401,7 +403,7 @@ class Excerpt(TypedPrintable, UserAuthored,
         return tplgroup + '/' + tplname
 
     def disabled_fields(self, ar):
-        rv = super(Excerpt, self).disabled_fields(ar)
+        rv = super().disabled_fields(ar)
         rv = rv | set(['excerpt_type', 'project'])
         if self.build_time:
             rv |= self.PRINTABLE_FIELDS
@@ -432,11 +434,11 @@ class Excerpt(TypedPrintable, UserAuthored,
         # existing sites
         et = self.excerpt_type
         if et is None or not et.certifying:
-            return super(Excerpt, self).filename_root()
+            return super().filename_root()
         assert et.certifying
         o = self.owner
         if o is None:
-            return super(Excerpt, self).filename_root()
+            return super().filename_root()
         name = o._meta.app_label + '.' + o.__class__.__name__
         if not et.primary:
             name += '.' + str(et.pk)
@@ -458,7 +460,7 @@ class Excerpt(TypedPrintable, UserAuthored,
                 if tpls is not None:
                     # print("20190506 Excerpt.get_print_templates()", tpls)
                     return tpls
-        return super(Excerpt, self).get_print_templates(bm, action)
+        return super().get_print_templates(bm, action)
         # ptype = self.get_printable_type()
         # # raise Exception("20150710 %s" % self.owner)
         # if ptype is not None and ptype.template:
@@ -467,7 +469,7 @@ class Excerpt(TypedPrintable, UserAuthored,
         # return [dd.plugins.excerpts.get_default_template(bm, self.owner)]
 
     # def get_recipient(self):
-    #     rec = super(Excerpt, self).get_recipient()
+    #     rec = super().get_recipient()
     #     if rec is None and hasattr(self.owner, 'recipient'):
     #         return self.owner.recipient
     #     return rec
@@ -517,7 +519,7 @@ class Excerpt(TypedPrintable, UserAuthored,
             return ar.html_text(ctx['body'])
 
     def before_printable_build(self, bm):
-        super(Excerpt, self).before_printable_build(bm)
+        super().before_printable_build(bm)
         if self.owner is not None:
             return self.owner.before_printable_build(bm)
 
@@ -529,7 +531,7 @@ class Excerpt(TypedPrintable, UserAuthored,
         """
         if self.owner is not None:
             kw = self.owner.get_printable_context(ar, **kw)
-        kw = super(Excerpt, self).get_printable_context(**kw)
+        kw = super().get_printable_context(**kw)
         kw.update(obj=self.owner)
         kw.update(excerpt=self)
         body = ''
@@ -564,7 +566,7 @@ class Excerpt(TypedPrintable, UserAuthored,
             "body_template_content "
             "company contact_person language "
             "user build_method")
-        super(Excerpt, cls).on_analyze(site)
+        super().on_analyze(site)
 
 
 # TODO: why not use full_clean() for the following?
@@ -666,13 +668,13 @@ class Excerpts(dd.Table):
 
     @classmethod
     def get_simple_parameters(cls):
-        s = list(super(Excerpts, cls).get_simple_parameters())
+        s = list(super().get_simple_parameters())
         s.append('excerpt_type')
         return s
 
     @classmethod
     def get_request_queryset(cls, ar):
-        qs = super(Excerpts, cls).get_request_queryset(ar)
+        qs = super().get_request_queryset(ar)
         pv = ar.param_values
 
         if pv.pcertifying == dd.YesNo.yes:
