@@ -4,7 +4,7 @@
 
 """Adds functionality for managing financial vouchers.
 
-See :doc:`/specs/finan`.
+See :doc:`/plugins/finan`.
 
 .. autosummary::
    :toctree:
