@@ -33,12 +33,14 @@ class GoogleSynchronized(dd.Model):
             return True
 
 
-class GoogleCalendarSynchronized(GoogleSynchronized, Modified):
+class GoogleCalendarSynchronized(GoogleSynchronized):
     class Meta:
         abstract = True
 
     if dd.is_installed('google'):
 
+        modified = models.DateTimeField(_("Modified"), editable=False, null=True)
+
         def insert_or_update_into_google(self, crs, user):
             body = {
                 'summary': self.name,
