@@ -100,7 +100,7 @@ class Household(contacts.Partner):
         verbose_name_plural = _("Households")
 
     memo_command = 'household'
-    
+
     type = dd.ForeignKey(Type, blank=True, null=True)
     # head = dd.ForeignKey('contacts.Person', verbose_name=_("Chef")),
 
@@ -139,7 +139,7 @@ class Household(contacts.Partner):
             return "{} ({})".format(self.get_full_name(), self.type)
         return str(self.get_full_name())
 
-    def get_name_elems(self, ar):
+    def get_name_elems(self, ar, sep=E.br):
         elems = []
         if self.prefix:
             elems += [self.prefix, ' ']
@@ -566,7 +566,7 @@ class MembersByPerson(Members):
             elems.append(E.ul(*items))
 
         if self.insert_action is not None:
-            sar = self.insert_action.request_from(ar)
+            sar = self.insert_action.request_from(ar, master_instance=obj)
             if sar.get_permission():
                 elems.append(E.br())
                 sar.known_values.update(person=obj)
