@@ -1,18 +1,8 @@
-# Copyright 2014-2015 Rumma & Ko Ltd
-#
+# Copyright 2014-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-"""Defines "parency links" between two "persons", and a user interface
-to manage them.
+"""Adds functionality to manage "parency links" between two "persons".
 
-This module is probably useful in combination with
-:mod:`lino_xl.lib.households`.
-
-.. autosummary::
-   :toctree:
-
-    choicelists
-    models
 
 """
 
@@ -30,11 +20,11 @@ class Plugin(ad.Plugin):
     application.  Default value is ``'contacts.Person'`` (referring to
     :class:`lino_xl.lib.contacts.Person`).
     """
-    
+
     def on_site_startup(self, site):
         self.person_model = site.models.resolve(self.person_model)
         super(Plugin, self).on_site_startup(site)
-        
+
 
     def setup_explorer_menu(self, site, user_type, m):
         # mg = site.plugins.contacts
@@ -42,5 +32,3 @@ class Plugin(ad.Plugin):
         m = m.add_menu(mg.app_label, mg.verbose_name)
         m.add_action('humanlinks.Links')
         m.add_action('humanlinks.LinkTypes')
-
-
