@@ -1,10 +1,11 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2020 Rumma & Ko Ltd
+# Copyright 2016-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
 from lino.api import dd, rt, _
 from lino.modlib.users.mixins import StartPlan
+from .mixins import InvoicingAreas
 
 
 class StartInvoicing(StartPlan):
@@ -15,17 +16,17 @@ class StartInvoicing(StartPlan):
         return rt.models.invoicing.Plan
 
 
-# class StartInvoicingByArea(StartInvoicing):
-#     show_in_bbar = True
-#
-#     def get_options(self, ar):
-#         area = ar.master_instance
-#         assert isinstance(area, rt.models.invoicing.Area)
-#         return dict(invoicing_area=area, partner=None)
+class StartInvoicingByArea(StartInvoicing):
+    show_in_toolbar = True
+
+    def get_options(self, ar):
+        mi = ar.master_instance
+        # assert isinstance(mi, rt.models.invoicing.Area)
+        return dict(invoicing_area=mi, partner=None)
 
 
 class StartInvoicingForPartner(StartInvoicing):
-    show_in_bbar = True
+    show_in_toolbar = True
     select_rows = True
     update_after_start = True
 
@@ -36,14 +37,16 @@ class StartInvoicingForPartner(StartInvoicing):
 
 
 class StartInvoicingForOrder(StartInvoicing):
-    show_in_bbar = True
+    show_in_toolbar = True
     select_rows = True
     update_after_start = True
 
     def get_options(self, ar):
         order = ar.selected_rows[0]
         assert isinstance(order, dd.plugins.invoicing.order_model)
-        return dict(order=order, partner=None, area=order.get_invoicing_area())
+        return dict(order=order, partner=None, invoicing_area=InvoicingAreas.default)
+        # return dict(order=order, partner=None)
+        # return dict(order=order, partner=None, invoicing_area=order.get_invoicing_area())
         # return dict(order=order, partner=None, area=order.journal.room.invoicing_area)
 
 
@@ -62,7 +65,7 @@ class ExecutePlan(dd.Action):
 class ExecuteItem(ExecutePlan):
     label = _("Execute item")
     show_in_workflow = True
-    show_in_bbar = False
+    show_in_toolbar = False
 
 
     def get_action_permission(self, ar, obj, state):
