@@ -1,16 +1,9 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-
-
-"""Utilities for this plugin.
-
-See :doc:`/specs/ledger`
-
-"""
+# Documentation: https://dev.lino-framework.org/plugins/ledger.html
 
 from decimal import Decimal, ROUND_HALF_UP
-from lino.api import _
 from .choicelists import DC
 
 ZERO = Decimal(0)
@@ -19,14 +12,6 @@ HUNDRED = Decimal('100.00')
 ONE = Decimal('1.00')
 MAX_AMOUNT = Decimal("9999999.00")
 
-# DC.debit = False
-# DC.credit = True
-#
-# DCLABELS = {
-#     DC.debit: _("Debit"),
-#     DC.credit: _("Credit")
-# }
-
 
 class Balance(object):
 
