@@ -33,7 +33,7 @@ class PrintMembers(DirectPrintAction):
     tplname = "list_members"
     build_method = "weasy2pdf"
     icon_name = None
-    show_in_bbar = False
+    show_in_toolbar = False
     # parameters = Monthly(
     #     show_remarks=models.BooleanField(
     #         _("Show remarks"), default=False),
