@@ -8,8 +8,5 @@ class Plugin(ad.Plugin):
 
     verbose_name = _("Measurements")
 
-    needs_plugins = ['django_measurement']
-
     def get_requirements(self, site):
-        pass
-        # yield 'django-measurement'
+        yield 'django-measurement'
