@@ -86,6 +86,8 @@ class InvoicesByOrder(InvoicesByPartner):
     def get_master_instance(cls, ar, model, pk):
         # the master instance of InvoicesByPartner must be a Partner, but since
         # we use this on an order, we get the pk of an order
+        if not pk:
+            return None
 
         assert model is rt.models.contacts.Partner
         order = rt.models.orders.Order.objects.get(pk=pk)
