@@ -1,4 +1,4 @@
-# Copyright 2017-2020 Rumma & Ko Ltd
+# Copyright 2017-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.core.validators import validate_email, URLValidator
@@ -42,6 +42,10 @@ class URL(ContactDetailType):
         txt = obj.remark or obj.value
         return E.a(txt, href=obj.value)
 
+class TEL(ContactDetailType):
+    def as_html(self, obj, ar):
+        return E.a(obj.value, href="tel:" + obj.value)
+
 
 
 class ContactDetailTypes(dd.ChoiceList):
@@ -52,8 +56,8 @@ class ContactDetailTypes(dd.ChoiceList):
 
 add = ContactDetailTypes.add_item_instance
 add(EMAIL('010', _("E-Mail"), 'email', field_name="email"))
-add(STD('020', _("Mobile"), 'gsm', field_name="gsm"))
-add(STD('030', _("Phone"), 'phone', field_name="phone"))
+add(TEL('020', _("Mobile"), 'gsm', field_name="gsm"))
+add(TEL('030', _("Phone"), 'phone', field_name="phone"))
 add(URL('040', _("Website"), 'url', field_name="url"))
 add(STD('050', _("Fax"), 'fax', field_name="fax"))
 add(STD('090', _("Other"), 'other'))
