@@ -1,17 +1,25 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2019 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino.utils.instantiator import Instantiator
 from lino_xl.lib.products.choicelists import ProductTypes
 
-from lino.api import dd, _
+from lino.api import dd, rt, _
 
 
 def objects():
 
     productcat = Instantiator('products.Category').build
-    product = Instantiator('products.Product', "sales_price category").build
+    # product = Instantiator('products.Product', "sales_price category").build
+
+    def product(price, cat, **kwargs):
+        cat = rt.models.products.Category.objects.get(pk=cat)
+        drv = dd.plugins.products.barcode_driver
+        if drv is not None:
+            kwargs.update(barcode=drv.pop_demo_value())
+        return rt.models.products.Product(sales_price=price, category=cat, **kwargs)
+
 
     furniture = productcat(
         id=1, product_type=ProductTypes.default, **dd.babel_values(
