@@ -231,7 +231,7 @@ class MySessions(Sessions):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MySessions, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(user=ar.get_user())
         return kw
 
@@ -241,7 +241,7 @@ class MySessionsByDate(MySessions):
     label = _("My sessions by date")
     column_names = (
         'start_time:5 end_time:5 break_time:6 duration:5 summary ticket '
-        'site_ref:10 workflow_buttons:10 *')
+        'workflow_buttons:10 site_ref:10 *')
 
     @classmethod
     def param_defaults(self, ar, **kw):
@@ -708,7 +708,7 @@ class WorkedHours(DaysTable, dd.VentilatingTable):
     # def get_request_queryset(cls, ar, **filter):
         # lst = list(super(WorkedHours, cls).get_data_rows(ar))
         # return list(reversed(lst))
-        return reversed(list(super(WorkedHours, cls).get_data_rows(ar)))
+        return reversed(list(super().get_data_rows(ar)))
 
     @classmethod
     def row_as_paragraph(cls, ar, row):
@@ -794,6 +794,8 @@ class MySessionsByDay(MySessionsByDate):
 
     @classmethod
     def get_master_instance(cls, ar, model, pk):
+        if not pk:
+            pk = 0
         return model(int(pk), ar, 'day')
 
     @classmethod
